==> goods-center-api-2.8.3-sources.jar: cn/com/duiba/goods/center/api/request/equity/FindPageRequest.java <==
package cn.com.duiba.goods.center.api.request.equity;

import cn.com.duiba.goods.center.api.remoteservice.enums.EquityExchangeStatusEnum;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @program: activity-all
 * @description: 查询分页条件
 * @author: Simba
 * @create: 2019-07-08 10:56
 **/
public class FindPageRequest implements Serializable {

    private static final long serialVersionUID = -8167217850552692829L;
    private Long appId;

    private List<Long> equityIdList;

    private String code;

    private EquityExchangeStatusEnum statusEnum;

    private Date startTime;

    private Date endTime;

    private Integer pageNo;

    private Integer pageSize;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public List<Long> getEquityIdList() {
        return equityIdList;
    }

    public void setEquityIdList(List<Long> equityIdList) {
        this.equityIdList = equityIdList;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public EquityExchangeStatusEnum getStatusEnum() {
        return statusEnum;
    }

    public void setStatusEnum(EquityExchangeStatusEnum statusEnum) {
        this.statusEnum = statusEnum;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getPageNo() {
        return pageNo;
    }

    public void setPageNo(Integer pageNo) {
        this.pageNo = pageNo;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }
}

==> goods-center-api-2.8.62-sources.jar: cn/com/duiba/goods/center/api/request/equity/FindPageRequest.java <==
package cn.com.duiba.goods.center.api.request.equity;

import cn.com.duiba.goods.center.api.remoteservice.enums.EquityExchangeStatusEnum;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @program: activity-all
 * @description: 查询分页条件
 * @author: Simba
 * @create: 2019-07-08 10:56
 **/
public class FindPageRequest implements Serializable {

    private static final long serialVersionUID = -8167217850552692829L;
    private Long appId;

    private List<Long> equityIdList;

    private String code;

    private EquityExchangeStatusEnum statusEnum;

    private Date startTime;

    private Date endTime;

    private Integer pageNo;

    private Integer pageSize;

    private Long merchantId;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public List<Long> getEquityIdList() {
        return equityIdList;
    }

    public void setEquityIdList(List<Long> equityIdList) {
        this.equityIdList = equityIdList;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public EquityExchangeStatusEnum getStatusEnum() {
        return statusEnum;
    }

    public void setStatusEnum(EquityExchangeStatusEnum statusEnum) {
        this.statusEnum = statusEnum;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getPageNo() {
        return pageNo;
    }

    public void setPageNo(Integer pageNo) {
        this.pageNo = pageNo;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }
}
